## Comparing Deep Learning models for rice mapping in Bhutan using high resolution satellite imagery

This repo contains the workflow for our Second Paper (In Review), where we compared different Deep Learning based models (namely Deep Neural Networks DNN and U-Net).

If you are looking to play around, you can download training (70\%), testing (10\%) and validation (20\%) data from [this](gs://bhutan-aces/unet_256x256_planet_wo_indices) public Google Storage Bucket. Learn how to programmatically access it [here](https://cloud.google.com/storage/docs/gsutil/commands/cp). Once you have downloaded the trainig data, you can start training using [`examples/run_model_example.py`](https://github.com/SERVIR/servir-aces/blob/main/examples/run_model_example.py) script. All the parameters can be changed via the `.env` file (copy [`.env.example`](https://github.com/SERVIR/servir-aces/blob/main/.env.example) file and rename it). Explanation can be found at the [docs](https://servir.github.io/servir-aces/).

Once the model is trained, then you can export your image as tfrecords for prediction purposes using [`4.export_image_for_prediction.py`](https://github.com/SERVIR/servir-aces/blob/main/workflow/v2/4.export_image_for_prediction.py) and then use `5.prediction_xxx.py` script (depending on dnn or unet model) to do the prediction. If instead you want to use Google's Vertex AI platform, you can use [`host_vertex_ai.py`](https://github.com/SERVIR/servir-aces/blob/main/workflow/v2/host_vertex_ai.py) script (use with cautions as this script may have changed and incur cost).
